@@ -75,6 +75,7 @@ use crate::ffi::ZStr;
 #[cfg(any(target_os = "ios", target_os = "macos"))]
 use crate::ffi::ZString;
 use crate::io::{self, OwnedFd, SeekFrom};
+use core::convert::TryInto;
 #[cfg(any(target_os = "android", target_os = "linux"))]
 use core::mem::size_of;
 #[cfg(target_os = "linux")]
@@ -787,7 +788,11 @@ pub(crate) fn getpath(fd: BorrowedFd<'_>) -> io::Result<ZString> {
 
     let l = buf.iter().position(|&c| c == 0).unwrap();
     buf.truncate(l);
-    buf.shrink_to(l + 1);
+
+    // TODO: On Rust 1.56, we can use `shrink_to` here.
+    //buf.shrink_to(l + 1);
+    buf.shrink_to_fit();
+
     Ok(ZString::new(buf).unwrap())
 }
 
