@@ -19,6 +19,7 @@ use super::{
 use crate::as_ptr;
 use crate::io::{self, OwnedFd};
 use crate::net::{SocketAddrAny, SocketAddrV4, SocketAddrV6};
+use core::convert::TryInto;
 use core::mem::{size_of, MaybeUninit};
 #[cfg(not(any(target_os = "redox", target_os = "wasi",)))]
 use core::ptr::null_mut;
@@ -397,8 +398,12 @@ pub(crate) mod sockopt {
     use crate::net::Ipv6Addr;
     use crate::net::{Ipv4Addr, SocketType};
     use crate::{as_mut_ptr, io};
+    use core::convert::TryInto;
     use core::time::Duration;
 
+    // TODO: With Rust 1.53 we can use `Duration::ZERO` instead.
+    const DURATION_ZERO: Duration = Duration::from_secs(0);
+
     #[inline]
     fn getsockopt<T>(fd: BorrowedFd<'_>, level: i32, optname: i32) -> io::Result<T> {
         use super::*;
@@ -485,7 +490,12 @@ pub(crate) mod sockopt {
     #[inline]
     pub(crate) fn get_socket_linger(fd: BorrowedFd<'_>) -> io::Result<Option<Duration>> {
         let linger: c::linger = getsockopt(fd, c::SOL_SOCKET as _, c::SO_LINGER)?;
-        Ok((linger.l_onoff != 0).then(|| Duration::from_secs(linger.l_linger as u64)))
+        // TODO: With Rust 1.50, this could use `.then`.
+        Ok(if linger.l_onoff != 0 {
+            Some(Duration::from_secs(linger.l_linger as u64))
+        } else {
+            None
+        })
     }
 
     #[cfg(any(target_os = "android", target_os = "linux"))]
@@ -508,7 +518,7 @@ pub(crate) mod sockopt {
     ) -> io::Result<()> {
         let timeout = match timeout {
             Some(timeout) => {
-                if timeout == Duration::ZERO {
+                if timeout == DURATION_ZERO {
                     return Err(io::Error::INVAL);
                 }
 
